﻿using System;
using System.Windows.Forms;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.WinForms;

namespace ClusterPoint
{
    public partial class Form1 : Form
    {
        private ClassBreakStyle classBreakStyle;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            winformsMap1.MapUnit = GeographyUnit.DecimalDegree;

            winformsMap1.Overlays.Add(new WorldStreetsAndImageryOverlay());

            ClusterPointStyle clusterPointStyle = new ClusterPointStyle();
            clusterPointStyle.MinimumFeaturesPerCellToCluster = 1;
            clusterPointStyle.CellSize = 30;

            clusterPointStyle.TextStyle = TextStyles.CreateSimpleTextStyle("FeatureCount", "Arail", 12, DrawingFontStyles.Bold, GeoColor.SimpleColors.Black);
            clusterPointStyle.TextStyle.PointPlacement = PointPlacement.UpperRight;
            clusterPointStyle.TextStyle.OverlappingRule = LabelOverlappingRule.AllowOverlapping;

            clusterPointStyle.DrawingClusteredFeature += ClusterPointStyle_DrawingClusteredFeature;

            ShapeFileFeatureLayer shapeFileFeatureLayer = new ShapeFileFeatureLayer("../../AppData/usEarthquake.shp");
            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(clusterPointStyle);
            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay layerOverlay = new LayerOverlay();
            layerOverlay.Layers.Add(shapeFileFeatureLayer);
            winformsMap1.Overlays.Add(layerOverlay);

            winformsMap1.CurrentExtent = new RectangleShape(-130, 60, -60, 15);
            winformsMap1.Refresh();
        }

        private void ClusterPointStyle_DrawingClusteredFeature(object sender, DrawingClusteredFeatureClusterPointStyleEventArgs e)
        {
            e.Styles[0] = new PointStyle(new GeoImage("../../AppData/Vehicle.png"));
            classBreakStyle = classBreakStyle ?? GetClassBreakStyle("FeatureCount");
            e.Styles.Add(classBreakStyle);
        }

        private ClassBreakStyle GetClassBreakStyle(string columnName)
        {
            ClassBreakStyle classBreakStyle = new ClassBreakStyle();
            classBreakStyle.ColumnName = columnName;

            PointStyle pointStyle1 = new PointStyle(new GeoImage("../../AppData/Vehicle.png"));
            classBreakStyle.ClassBreaks.Add(new ClassBreak(1, pointStyle1));

            PointStyle pointStyle2 = new PointStyle(new GeoImage("../../AppData/Vehicle2.png"));
            classBreakStyle.ClassBreaks.Add(new ClassBreak(5, pointStyle2)); // More than 5


            return classBreakStyle;
        }
    }
}
